open_window_at_position

Function open_window_at_position 

pub fn open_window_at_position(
    state: &Arc<AppState>,
    args: &Value,
) -> Result<Value, String>
Open a new window at a specific screen position (tear-off). Creates a new CEF browser window positioned so the cursor lands in the title bar.