register_backend_window

Function register_backend_window 

pub fn register_backend_window(_state: &Arc<AppState>, args: &Value) -> Value
Register the backend window ID for a window label. Called by the frontend after it has initialized its backend Window object. Used by on_before_close to notify the backend when a secondary window closes.