should_emit

Function should_emit 

pub fn should_emit(hwnd: u64) -> bool
Phase B.9.1 — should we emit a position report for this HWND right now? Returns true if at least DEBOUNCE_MS has elapsed since the last emit for this HWND (or this is the first emit for it). Updates the timestamp atomically with the decision.